@@ -1,10 +1,23 @@
-// -*- c++ -*-
+/* 
+ *  Copyright (C) 1999-2002 Bernd Gehrmann
+ *                          bernd@mail.berlios.de
+ *
+ * This program may be distributed under the terms of the Q Public
+ * License as defined by Trolltech AS of Norway and appearing in the
+ * file LICENSE.QPL included in the packaging of this file.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
+
 
 #ifndef CERVISIASHELL_H
 #define CERVISIASHELL_H
 
 #include <kparts/mainwindow.h>
 
+class QLabel;
 class CervisiaPart;
 class KRecentFilesAction;
 
@@ -24,10 +37,12 @@ public:
 
 public slots:
     void slotOpenSandbox();
-    void slotToggleToolbar( bool visible );
     void slotConfigureKeys();
     void slotConfigureToolBars();
     void slotExit();
+    
+protected slots:
+    void slotChangeFilterStatus(QString status);
 
 protected:
     void setupActions();
@@ -38,6 +53,7 @@ protected:
 
 private:
     CervisiaPart *part;
+    QLabel *filterLabel;
 
 };
 
