@@ -1,6 +1,6 @@
 /* 
- *  Copyright (C) 1999-2001 Bernd Gehrmann
- *                          bernd@physik.hu-berlin.de
+ *  Copyright (C) 1999-2002 Bernd Gehrmann
+ *                          bernd@mail.berlios.de
  *
  * This program may be distributed under the terms of the Q Public
  * License as defined by Trolltech AS of Norway and appearing in the
@@ -12,8 +12,8 @@
  */
 
 
-#ifndef _CVSDIR_H_
-#define _CVSDIR_H_
+#ifndef CVSDIR_H
+#define CVSDIR_H
 
 #include <qdir.h>
 
