@@ -24,29 +24,17 @@
 ListViewItem::ListViewItem(ListView *parent)
     : QListViewItem(parent)
 {
-    hiddenChild = 0;
-    hiddenSibling = 0;
-    formerParent = 0;
 }
 
 
 ListViewItem::ListViewItem(ListViewItem *parent)
     : QListViewItem(parent)
 {
-    hiddenChild = 0;
-    hiddenSibling = 0;
-    formerParent = 0;
 }
 
 
 ListViewItem *ListViewItem::myFirstChild() const
 {
-    if (!visible())
-        return 0;
-    
-    if (hiddenChild)
-        return hiddenChild;
-
     // Cast guaranteed by ListViewItem's constructor
     // (provided no other QListViewItems are constructed)
     return static_cast<ListViewItem*>(firstChild());
@@ -55,53 +43,13 @@ ListViewItem *ListViewItem::myFirstChild() const
 
 ListViewItem *ListViewItem::myNextSibling() const
 {
-    if (visible())
-        return static_cast<ListViewItem*>(nextSibling());
-
-    if (hiddenSibling)
-        return hiddenSibling;
-
-    // We're the last hidden item of our parent
-    return static_cast<ListViewItem*>(formerParent->firstChild());
-}
-
-
-void ListViewItem::setVisible(bool b)
-{
-    if (visible() == b)
-        return;
-
-    if (b)
-        {
-            ListViewItem *item = formerParent->hiddenChild;
-            if (item == this)
-                formerParent->hiddenChild = item->hiddenSibling;
-            else
-                {
-                    // Loop should be finite...
-                    while (item->hiddenSibling != this)
-                        item = item->hiddenSibling;
-                    item->hiddenSibling = this->hiddenSibling;
-                }
-            formerParent->insertItem(this);
-            formerParent = 0;
-        }
-    else
-        {
-            // Cast guaranteed by constructor
-            ListViewItem *p = static_cast<ListViewItem*>(parent());
-            ListViewItem *item = p->hiddenChild;
-            this->hiddenSibling = item;
-            p->hiddenChild = this;
-            formerParent = p;
-            p->takeItem(this);
-        }
+    return static_cast<ListViewItem*>(nextSibling());
 }
 
 
 bool ListViewItem::visible() const
 {
-    return formerParent == 0;
+    return isVisible();
 }
 
 
