@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 1999-2001 Bernd Gehrmann
- *                          bernd@physik.hu-berlin.de
+ *  Copyright (C) 1999-2002 Bernd Gehrmann
+ *                          bernd@mail.berlios.de
  *
  * This program may be distributed under the terms of the Q Public
  * License as defined by Trolltech AS of Norway and appearing in the
@@ -12,6 +12,8 @@
  */
 
 
+#include "logdlg.h"
+
 #include <stdio.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
@@ -19,19 +21,17 @@
 #include <qwhatsthis.h>
 #include <kbuttonbox.h>
 #include <kdebug.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kconfig.h>
 #include <kprocess.h>
 #include <diffdlg.h>
-#include <annotatedlg.h>
+
+#include "annotatedlg.h"
 #include "cvsprogressdlg.h"
 #include "misc.h"
 
-#include "logdlg.h"
-#include "logdlg.moc"
-
 
 LogDialog::Options *LogDialog::options = 0;
 
@@ -50,18 +50,15 @@ LogDialog::LogDialog(QWidget *parent, const char *name)
 	     this, SLOT(revisionSelected(QString,bool)) );
 
     QWidgetStack *stack = new QWidgetStack(this);
-#if QT_VERSION < 300
-    stack->setPalettePropagation(NoChildren);
-#endif
     tabbar = new QTabBar(this);
     QTab *tab1 = new QTab(i18n("&Tree"));
     stack->addWidget(tree, tabbar->addTab(tab1));
     QTab *tab2 = new QTab(i18n("&List"));
     stack->addWidget(list, tabbar->addTab(tab2));
 
-    tabbar->adjustSize();
-    tabbar->setMinimumWidth(tabbar->width());
-    tabbar->setFixedHeight(tabbar->height());
+    //    tabbar->adjustSize();
+    //    tabbar->setMinimumWidth(tabbar->width());
+    //    tabbar->setFixedHeight(tabbar->height());
     layout->addWidget(tabbar, 0);
     layout->addWidget(stack, 3);
     
@@ -79,7 +76,7 @@ LogDialog::LogDialog(QWidget *parent, const char *name)
 	{
 	    QFrame *frame = new QFrame(this);
 	    frame->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-            //	    frame->setMinimumHeight(frame->sizeHint().height());
+
 	    layout->addSpacing(8);
 	    layout->addWidget(frame);
 	    layout->addSpacing(8);
@@ -134,12 +131,13 @@ LogDialog::LogDialog(QWidget *parent, const char *name)
 
             commentbox[i] = new QTextEdit(this);
 	    commentbox[i]->setReadOnly(true);
-	    commentbox[i]->setMinimumSize(10,10);
+            fm = commentbox[i]->fontMetrics();
+	    commentbox[i]->setFixedHeight(2*fm.lineSpacing()+10);
 	    grid->addMultiCellWidget(commentbox[i], 2, 2, 1, 3);
 
             tagsbox[i] = new QTextEdit(this);
 	    tagsbox[i]->setReadOnly(true);
-	    tagsbox[i]->setMinimumSize(10,10);
+	    tagsbox[i]->setFixedHeight(2*fm.lineSpacing()+10);
             grid->addWidget(tagsbox[i], 2, 4);
 	}
 
@@ -156,21 +154,28 @@ LogDialog::LogDialog(QWidget *parent, const char *name)
 
     QFrame *frame = new QFrame(this);
     frame->setFrameStyle(QFrame::HLine | QFrame::Sunken);
+
     layout->addSpacing(8);
     layout->addWidget(frame, 0);
     layout->addSpacing(8);
 
     KButtonBox *buttonbox = new KButtonBox(this);
-    connect( buttonbox->addButton(i18n("&Diff")), SIGNAL(clicked()),
-	     SLOT(diffClicked()) );
-    connect( buttonbox->addButton(i18n("&Annotate")), SIGNAL(clicked()),
-	     SLOT(annotateClicked()) );
+    QPushButton *helpbutton = buttonbox->addButton(i18n("&Help"));
+    helpbutton->setAutoDefault(false);
     buttonbox->addStretch();
+    QPushButton *diffbutton = buttonbox->addButton(i18n("&Diff"));
+    diffbutton->setAutoDefault(false);
+    QPushButton *annotatebutton = buttonbox->addButton(i18n("&Annotate"));
+    annotatebutton->setAutoDefault(false);
     connect( buttonbox->addButton(i18n("&Close")), SIGNAL(clicked()),
 	     SLOT(reject()) );
     buttonbox->layout();
     layout->addWidget(buttonbox, 0);
 
+    connect( helpbutton, SIGNAL(clicked()), SLOT(helpClicked()) );
+    connect( diffbutton, SIGNAL(clicked()), SLOT(diffClicked()) );
+    connect( annotatebutton, SIGNAL(clicked()), SLOT(annotateClicked()) );
+
     if (options)
         {
             resize(options->size);
@@ -225,9 +230,9 @@ bool LogDialog::parseCvsLog(const QString &sbox, const QString &repo, const QStr
     repository = repo;
     filename = fname;
     
-    setCaption(i18n("CVS Log: ") + filename);
+    setCaption(i18n("CVS Log: %1").arg(filename));
 
-    QString cmdline = cvsClient(repository) + " -f log ";
+    QString cmdline = cvsClient(repository) + " log ";
     cmdline += KShellProcess::quote(filename);
     
     CvsProgressDialog l("Logging", this);
@@ -236,7 +241,7 @@ bool LogDialog::parseCvsLog(const QString &sbox, const QString &repo, const QStr
         return false;
 
     state = Begin;
-    QCString line;
+    QString line;
     while ( l.getOneLine(&line) )
         {
             switch (state)
@@ -298,7 +303,7 @@ bool LogDialog::parseCvsLog(const QString &sbox, const QString &repo, const QStr
                     state = Branches;
                     break;
                 case Branches:
-                    if (qstrncmp(line, "branches:", 9) != 0)
+                    if (!line.startsWith("branches:"))
                         {
                             comment = line;
                             state = Comment;
@@ -395,6 +400,12 @@ bool LogDialog::parseCvsLog(const QString &sbox, const QString &repo, const QStr
 }
 
 
+void LogDialog::helpClicked()
+{
+    kapp->invokeHelp("browsinglogs", "cervisia");
+}
+
+
 void LogDialog::diffClicked()
 {
     if (selectionA.isEmpty() || selectionB.isEmpty())
@@ -477,6 +488,8 @@ void LogDialog::tagBSelected(int n)
         tagSelected(tags.at(n-1)->tag, true);
 }
 
+#include "logdlg.moc"
+
 // Local Variables:
 // c-basic-offset: 4
 // End:
