@@ -22,7 +22,7 @@
 #include <qdir.h>
 #include <qfileinfo.h>
 #include <qheader.h>
-#include <qstack.h>
+#include <qptrstack.h>
 #include <kapplication.h>
 #include <kdebug.h>
 #include <kfileview.h>
@@ -619,9 +619,14 @@ QString UpdateViewItem::text(int col) const
 		return m_tag;
 	case 4:
 		{
-			QDateTime timestamp;
-			timestamp.setTime_t(m_timestamp);
-			return KGlobal::locale()->formatDateTime(timestamp);
+			if (m_status != UpdateView::NotInCVS)            
+				{
+					QDateTime timestamp;
+					timestamp.setTime_t(m_timestamp);
+					return KGlobal::locale()->formatDateTime(timestamp);
+				} else {
+					return "";
+				}
 	    }
 	default:
 	    return "";
