@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-		2001-2002 by Stanislav Visnovsky <visnovsky@kde.org>
+		2001-2003 by Stanislav Visnovsky <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -315,13 +315,10 @@ void CatalogManager::setupActions()
     KStdAction::preferences(this, SLOT( optionsPreferences()), actionCollection());
     KStdAction::keyBindings(this, SLOT( optionsKeys() ), actionCollection());
     KStdAction::configureToolbars(this,SLOT(optionsEditToolbars()), actionCollection() );
-    KToggleAction * toggle = KStdAction::showToolbar( this,SLOT( dummySlot() ), actionCollection() );
-    connect( toggle, SIGNAL( toggled(bool) ), this, SLOT( optionsShowToolbar(bool) ) );
-    toggle = new KToggleAction(i18n("Show &Navigationbar"), 0, actionCollection(),"settings_show_navbar");
-    toggle->setChecked(true);
-    connect(toggle,SIGNAL(toggled(bool)), this, SLOT(optionsShowNavigationbar(bool)));
-    toggle = KStdAction::showStatusbar( this,SLOT( dummySlot() ), actionCollection() );
+    KToggleAction * toggle = KStdAction::showStatusbar( this,SLOT( dummySlot() ), actionCollection() );
     connect( toggle, SIGNAL( toggled(bool) ), this, SLOT( optionsShowStatusbar(bool) ) );
+    
+    setStandardToolBarMenuEnabled ( true );
 
     // commands menus
     KActionMenu* actionMenu=new KActionMenu(i18n("Commands"), 0,
@@ -977,22 +974,6 @@ void CatalogManager::optionsShowStatusbar(bool on)
         statusBar()->hide();
 }
 
-void CatalogManager::optionsShowToolbar(bool on)
-{
-    if( on )
-        toolBar()->show();
-    else
-        toolBar()->hide();
-}
-
-void CatalogManager::optionsShowNavigationbar(bool on)
-{
-    if( on )
-        toolBar("navigationbar")->show();
-    else
-        toolBar("navigationbar")->hide();
-}
-
 bool CatalogManager::queryClose()
 {
     _catalogManager->stop();
@@ -1014,9 +995,6 @@ void CatalogManager::restoreView()
     KToggleAction * toggle = (KToggleAction*)actionCollection()->
 	action(KStdAction::stdName(KStdAction::ShowStatusbar));
     toggle->setChecked(!statusBar()->isHidden() );
-    toggle = (KToggleAction*)actionCollection()->
-	action(KStdAction::stdName(KStdAction::ShowToolbar));
-    toggle->setChecked(!toolBar()->isHidden() );
 }
 
 #include "catalogmanager.moc"
