@@ -506,7 +506,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
 			    KMessageBox::information(0,i18n("Free Software Foundation Copyright does not contain any year. "
 			    "It will not be updated."));
 			} else {
-			    (*it).insert(index+1, QString(",")+cy);
+			    (*it).insert(index+1, QString(", ")+cy);
 			}
 		    }
 	    }
@@ -547,7 +547,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
       {
          temp+=(" <"+d->_identitySettings.authorEmail+">");
       }
-      temp+=", "+QDate::currentDate().toString("yyyy");
+      temp+=", "+QDate::currentDate().toString("yyyy")+".";
       
       for( it = commentList.begin(); it != commentList.end(); ++it )
       {
@@ -587,8 +587,9 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
 		    //update years
 		    int index = (*ait).findRev( QRegExp("[\\d]+[\\d\\-, ]*") );
 		    if( index == -1 ) (*ait)+=", "+cy;
-		    else (*ait).insert(index+1, QString(",")+cy);
+		    else (*ait).insert(index+1, QString(", ")+cy);
 		}
+		
 	}
 	else foundAuthors.append(temp);
 	it=commentList.end();
@@ -597,7 +598,13 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
 	while( (*it).contains( QRegExp( "^#\\s*$")) || (*it).contains( QRegExp( "^#[:,\\.]")));
 	it++;
 	for( ait = foundAuthors.begin() ; ait != foundAuthors.end() ; ++ait )
-	    commentList.insert(it, (*ait));
+	{
+	    QString s = (*ait);
+
+	    // ensure dot at the end of copyright
+	    if( !s.endsWith(".") ) s += ".";
+	    commentList.insert(it, s);
+	}
    }
 
    QString comment;
@@ -667,7 +674,7 @@ void Catalog::setModified(bool flag)
     bool old=d->_modified;
     d->_modified=flag;
 
-    if(old!=d->_modified);
+    if(old!=d->_modified)
        emit signalModified(flag);
 }
 
@@ -678,7 +685,7 @@ QString Catalog::packageName() const
     
     QString package=d->_url.fileName();
 
-    int index=package.findRev(QRegExp(".pot?"));
+    int index=package.find(QRegExp("(\\."+d->_identitySettings.languageCode+")?\\.pot?$"));
 
     if(index>0)
       package=package.left(index);
