@@ -22,26 +22,37 @@
 
 **************************************************************************** */
 #include "catalogitem.h"
+#include "catalogitem_private.h"
 #include "editcmd.h"
 #include "resources.h"
 #include "libgettext/pofiles.h"
 
 #include "tagextractor.h"
+#include "argextractor.h"
 
 #include <qtextstream.h>
 #include <qtextcodec.h>
 #include <FlexLexer.h>
+#include <qdom.h>
 
 CatalogItem::CatalogItem()
-    : _tagList(0)
 {
+   d=0;
    clear();
 }
 
-CatalogItem::CatalogItem(QString itemStr)
-    : _tagList(0)
+CatalogItem::CatalogItem(const CatalogItem& item)
 {
+   d=0;
    clear();
+   *d=*(item.d);
+}
+
+CatalogItem::CatalogItem(QString itemStr)
+{
+   d=0;
+   clear();
+
    QTextStream stream(&itemStr,IO_ReadOnly);
 
    read(stream);
@@ -49,46 +60,55 @@ CatalogItem::CatalogItem(QString itemStr)
 
 CatalogItem::~CatalogItem()
 {
-    if(_tagList)
-        delete _tagList;
+    if( d ) delete d;
 }
 
 CatalogItem::CatalogItem(const char* msgid, const char* msgstr,
 			 const char* comment)
-    : _tagList(0)
 {
+   d=0;
     clear();
 
-    _comment=comment;
-    (*_msgid.begin())=msgid;
-    (*_msgstr.begin())=msgstr;
-    _valid=true;
-	_error = None;
+    d->_comment=comment;
+    (*(d->_msgid).begin())=msgid;
+    (*(d->_msgstr).begin())=msgstr;
+    d->_valid=true;
+    d->_error = None;
 }
 
 QString CatalogItem::comment() const
 {
-    return _comment;
+    return d->_comment;
 }
 
-QString CatalogItem::msgid() const
+QString CatalogItem::msgid(const bool noNewlines) const
 {
-    return _msgid.first();
+    QString result=d->_msgid.first();
+    if( noNewlines )
+    {
+	result.replace(QRegExp("\\n"),"");
+    }
+    return result;
 }
 
-QString CatalogItem::msgstr() const
+QString CatalogItem::msgstr(const bool noNewlines) const
 {
-    return _msgstr.first();
+    QString result=d->_msgstr.first();
+    if( noNewlines )
+    {
+	result.replace(QRegExp("\\n"),"");
+    }
+    return result;
 }
 
 
 QStringList CatalogItem::msgidAsList(bool plural) const
 {
    QString str;
-   if(_gettextPluralForm && plural)
-       str = _msgid.last();
+   if(d->_gettextPluralForm && plural)
+       str = d->_msgid.last();
    else
-       str = _msgid.first();
+       str = d->_msgid.first();
    
    QStringList list=QStringList::split("\n",str);
 
@@ -105,10 +125,10 @@ QStringList CatalogItem::msgidAsList(bool plural) const
 QStringList CatalogItem::msgstrAsList(int nr) const
 {
    QString str;
-   if(_gettextPluralForm && nr > 0)
+   if(d->_gettextPluralForm && nr > 0)
    {
-       QStringList::ConstIterator it = _msgstr.at(nr);
-       if(it != _msgstr.end())
+       QStringList::ConstIterator it = d->_msgstr.at(nr);
+       if(it != d->_msgstr.end())
        {
            str = *it;
        }
@@ -120,7 +140,7 @@ QStringList CatalogItem::msgstrAsList(int nr) const
    }
    else
    {
-       str = _msgstr.first();
+       str = d->_msgstr.first();
    }
    
    QStringList list=QStringList::split("\n",str);
@@ -141,23 +161,59 @@ QStringList CatalogItem::commentAsList() const
    return list;
 }
 
-
-const QStringList& CatalogItem::tagList()
+bool CatalogItem::isValid() const
 {
-    if(!_tagList)
+    return d->_valid;
+}
+
+void CatalogItem::setMsgid(QString msg)
+{
+    d->_msgid=msg;
+}
+
+void CatalogItem::setMsgstr(QString msg)
+{
+    d->_msgstr=msg;
+}
+
+void CatalogItem::setComment(QString com)
+{
+    d->_comment=com;
+}
+
+int CatalogItem::errors() const
+{
+    return d->_error;
+}
+
+QStringList CatalogItem::tagList()
+{
+    if(!d->_haveTagList)
     {
-        TagExtractor te(msgid());
-        _tagList = new QStringList(te.tags());
+        TagExtractor te(msgid(true));
+        d->_tagList = QStringList(te.tags());
+	d->_haveTagList = true;
     }
 
-    return *_tagList;
+    return d->_tagList;
+}
+
+QStringList CatalogItem::argList()
+{
+    if(!d->_haveArgList)
+    {
+        ArgExtractor te(msgid(true));
+        d->_argList = QStringList(te.args());
+    }
+
+    return d->_argList;
 }
 
 
 bool CatalogItem::isFuzzy() const
 {
    bool flag=false;
-   if( _comment.contains(", fuzzy") )
+   if( d->_comment.contains(", fuzzy") )
      flag=true;
 
    return flag;
@@ -166,7 +222,16 @@ bool CatalogItem::isFuzzy() const
 bool CatalogItem::isCformat() const
 {
    bool flag=false;
-   if(_comment.contains(", c-format"))
+   if(d->_comment.contains(", c-format"))
+     flag=true;
+
+   return flag;
+}
+
+bool CatalogItem::isNoCformat() const
+{
+   bool flag=false;
+   if(d->_comment.contains(", no-c-format"))
      flag=true;
 
    return flag;
@@ -174,29 +239,29 @@ bool CatalogItem::isCformat() const
 
 bool CatalogItem::isUntranslated() const
 {
-   return _msgstr.first().isEmpty();
+   return d->_msgstr.first().isEmpty();
 }
 
 bool CatalogItem::isPluralForm() const
 {
-    return _gettextPluralForm;
+    return d->_gettextPluralForm;
 }
 
 int CatalogItem::totalLines() const
 {
    int lines=0;
-   if(!_comment.isEmpty())
+   if(!d->_comment.isEmpty())
    {
-      lines = _comment.contains('\n')+1;
+      lines = d->_comment.contains('\n')+1;
    }
    int msgidLines=0;
    QStringList::ConstIterator it;
-   for(it=_msgid.begin(); it != _msgid.end(); ++it)
+   for(it=d->_msgid.begin(); it != d->_msgid.end(); ++it)
    {
       msgidLines += (*it).contains('\n')+1;
    }
    int msgstrLines=0;
-   for(it=_msgstr.begin(); it != _msgstr.end(); ++it)
+   for(it=d->_msgstr.begin(); it != d->_msgstr.end(); ++it)
    {
       msgstrLines += (*it).contains('\n')+1;
    }
@@ -215,9 +280,9 @@ int CatalogItem::totalLines() const
 void CatalogItem::setSyntaxError(bool on)
 {
 	if(on)
-		_error = _error | Syntax;
+		d->_error = d->_error | Syntax;
 	else
-		_error = _error & ~Syntax;
+		d->_error = d->_error & ~Syntax;
 }
 
 QPtrList<EditCommand> CatalogItem::removeFuzzy(bool doIt)
@@ -225,7 +290,7 @@ QPtrList<EditCommand> CatalogItem::removeFuzzy(bool doIt)
    QPtrList<EditCommand> editList;
    editList.setAutoDelete(false);
 
-   QString comment=_comment;
+   QString comment=d->_comment;
 
    if(isFuzzy())
    {
@@ -286,7 +351,7 @@ QPtrList<EditCommand> CatalogItem::removeFuzzy(bool doIt)
        }
        
        if(doIt)
-          _comment=comment;
+          d->_comment=comment;
 
    }
 
@@ -304,10 +369,10 @@ QPtrList<EditCommand> CatalogItem::addFuzzy(bool doIt)
    if(!isFuzzy())
    {
        EditCommand *cmd;
-       int offset=_comment.length();
+       int offset=d->_comment.length();
 
        QString addStr;
-       if(offset > 0 && _comment[offset-1] != '\n')
+       if(offset > 0 && d->_comment[offset-1] != '\n')
        {
            addStr='\n';
        }
@@ -319,7 +384,7 @@ QPtrList<EditCommand> CatalogItem::addFuzzy(bool doIt)
 
 
        if(doIt)
-          _comment+=addStr;
+          d->_comment+=addStr;
    }
 
    return editList;
@@ -348,22 +413,22 @@ void CatalogItem::processCommand(EditCommand* cmd, bool undo)
     {
        if(delcmd->part()==EditCommand::Msgstr)
        {
-          (*_msgstr.begin()).insert(delcmd->offset,delcmd->str);
+          (*(d->_msgstr).begin()).insert(delcmd->offset,delcmd->str);
        }
        else if(delcmd->part()==EditCommand::Comment)
        {
-          _comment.insert(delcmd->offset,delcmd->str);
+          d->_comment.insert(delcmd->offset,delcmd->str);
        }
     }
     else
     { // del
        if(delcmd->part()==EditCommand::Msgstr)
        {
-          (*_msgstr.begin()).remove(delcmd->offset,delcmd->str.length());
+          (*(d->_msgstr).begin()).remove(delcmd->offset,delcmd->str.length());
        }
        else if(delcmd->part()==EditCommand::Comment)
        {
-          _comment.remove(delcmd->offset,delcmd->str.length());
+          d->_comment.remove(delcmd->offset,delcmd->str.length());
        }
     }
 }
@@ -371,40 +436,49 @@ void CatalogItem::processCommand(EditCommand* cmd, bool undo)
 
 void CatalogItem::clear()
 {
-   _comment="";
-   _msgid.clear();
-   _msgid.append("");
-   _msgstr.clear();
-   _msgstr.append("");
-   _valid=true;
-   _error=None;
-   _gettextPluralForm=false;
+   if( !d ) d = new CatalogItemPrivate();
+   d->_comment="";
+   d->_msgid.clear();
+   d->_msgid.append("");
+   d->_msgstr.clear();
+   d->_msgstr.append("");
+   d->_valid=true;
+   d->_error=None;
+   d->_gettextPluralForm=false;
 
-   if(_tagList)
-   {
-       delete _tagList;
-       _tagList=0;
-   }
+   d->_tagList.clear();
+   d->_argList.clear();
+   d->_haveTagList=false;
+   d->_haveArgList=false;
 }
 
-
 bool CatalogItem::checkArgs(const QRegExp& comment) 
 {
-	if( !isCformat() ) return true;
+	if( isNoCformat() ) return true;
 	bool hasError = false;
 
 	if(!isUntranslated())
 	{
-		QString formatChars="dioxXucsfeEgGp%";
+		QString formatChars="dioxXucsfeEgGpn%";
 
-		QString line=_msgid.first();
+		QString line=msgid();
+		QStringList argList;
+		
+//		if( isPluralForm() ) 
+		{
+		    // FIXME: this is KDE specific
+		    if( line.startsWith("_n:" ))
+		    {
+			// truncate text after first \n to get args only once
+			line = line.mid(0,line.find("\\n"));
+		    }
+		}
 		line.replace( comment, "");
-		line.replace( QRegExp("\\n"), "" );
+		line.replace(QRegExp("\\n"),"");
 		line.simplifyWhiteSpace();
 		
 		int index=line.find(QRegExp("%."));
 		
-		QStringList argList;
 		while(index>=0)
 		{
 			int endIndex=line.find(QRegExp("[^\\d]"),index+1);
@@ -422,12 +496,43 @@ bool CatalogItem::checkArgs(const QRegExp& comment)
 	
 			index=line.find(QRegExp("%."),endIndex);
 		}
-	
-		line=_msgstr.first().simplifyWhiteSpace();
-		index=line.find(QRegExp("%."));
-
-		while(index>=0)
+		
+//		if( isPluralForm() ) 
 		{
+		    // FIXME: this is KDE specific
+		    if( line.startsWith("_n:" ) && !argList.contains("%n") )
+		    {
+			argList.append("%n");
+		    }
+		}
+		
+		// generate for each plural form to be checked separately
+		line=d->_msgstr.first();
+		QStringList lines;
+		
+		// FIXME; this is KDE specific
+		if( msgid().startsWith("_n:") )
+		{
+		    lines = QStringList::split("\\n",line);
+		}
+		else 
+		{
+		    lines.append(line);
+		}
+
+		QStringList argCache = argList;
+		
+		for(QStringList::Iterator i = lines.begin() ; i!=lines.end() ; i++)
+		{
+		    line=(*i);
+		    
+    		    line.replace(QRegExp("\\n"),"");
+		    index=line.find(QRegExp("%."));
+		    
+		    argList = argCache;
+
+		    while(index>=0)
+		    {
 			int endIndex=line.find(QRegExp("[^\\d]"),index+1);
 			if(endIndex<0)
 			{
@@ -452,21 +557,22 @@ bool CatalogItem::checkArgs(const QRegExp& comment)
 			}
 
 			index=line.find(QRegExp("%."),endIndex);
-		}
+		    }
 
-		if(!argList.isEmpty())
-		{
+		    if(!argList.isEmpty())
+		    {
 			hasError = true;
+		    }
 		}
 	}
 	
 	if(hasError)
 	{
-		_error = _error | Args;
+		d->_error = d->_error | Args;
 	}
 	else
 	{
-		_error = _error & ~Args;
+		d->_error = d->_error & ~Args;
 	}
 			
 	return !hasError;
@@ -478,35 +584,33 @@ bool CatalogItem::checkAccelerator(QChar accelMarker, const QRegExp& comment)
 	bool hasError = false;
 	if(!isUntranslated())
 	{
-		QString lineid=_msgid.first();
+		QString lineid=msgid();
 		lineid.replace( comment, "");
-		lineid.replace( QRegExp("\\n"), "" );
+		lineid.replace(QRegExp("\\n"),"");
 		lineid.simplifyWhiteSpace();
-		QString linestr=_msgstr.first();
-		linestr.replace( comment, "");
-		linestr.replace( QRegExp("\\n"), "" );
+		QString linestr=msgstr(true);
 		linestr.simplifyWhiteSpace();
 
 		QString regStr(accelMarker);
 		regStr+="[^\\s]";
 		QRegExp reg(regStr);
 		int n = lineid.contains(reg);
-		if( accelMarker = '&' ) 
-		    n = n - lineid.contains(QRegExp("&[a-z,A-Z,\\-,0-9,#]*;"));
+		if( accelMarker == '&' ) 
+		    n = n - lineid.contains(QRegExp("(&[a-z,A-Z,\\-,0-9,#]*;)|(&&(?!&+))"));
 		int m = linestr.contains(reg);
-		if( accelMarker = '&' ) 
-		    m = m - linestr.contains(QRegExp("&[a-z,A-Z,\\-,0-9,#]*;"));
+		if( accelMarker == '&' ) 
+		    m = m - linestr.contains(QRegExp("(&[a-z,A-Z,\\-,0-9,#]*;)|(&&(?!&+))"));
 
 		hasError = ( n<=1 &&  m != n);
 	}
 
 	if(hasError)
 	{
-		_error = _error | Accel;
+		d->_error = d->_error | Accel;
 	}
 	else
 	{
-		_error = _error & ~Accel;
+		d->_error = d->_error & ~Accel;
 	}
 			
 	return !hasError;
@@ -517,24 +621,24 @@ bool CatalogItem::checkEquation()
 {
 	bool error = false;
 	
-    QString msg=_msgid.first();
+    QString msg=d->_msgid.first();
 	if(!isUntranslated() && !msg.contains('\n') 
 					&& msg.contains(QRegExp("^[a-zA-Z0-9]+=.+")))
 	{
 		int index = msg.find('=');
 		QString left = msg.left(index);
-		index = _msgstr.first().find('=');
-		if(left != _msgstr.first().left(index))
+		index = d->_msgstr.first().find('=');
+		if(left != d->_msgstr.first().left(index))
 			error = true;
 	}
 	
 	if(error)
 	{
-		_error = _error | Equation;
+		d->_error = d->_error | Equation;
 	}
 	else
 	{
-		_error = _error & ~Equation;
+		d->_error = d->_error & ~Equation;
 	}
 
 	return !error;
@@ -545,19 +649,19 @@ bool CatalogItem::checkForContext(const QRegExp& reg)
 {
 	bool error = false;
 
-	if(!isUntranslated() && _msgid.first().contains(reg) 
-            && _msgstr.first().contains(reg))
+	if(!isUntranslated() && d->_msgid.first().contains(reg) 
+            && d->_msgstr.first().contains(reg))
 	{
 		error = true;
 	}
 	
 	if(error)
 	{
-		_error = _error | Context;
+		d->_error = d->_error | Context;
 	}
 	else
 	{
-		_error = _error & ~Context;
+		d->_error = d->_error & ~Context;
 	}
 
 	return !error;
@@ -567,13 +671,13 @@ bool CatalogItem::checkSingularPlural(const QRegExp& reg, const int neededLines)
 {
 	bool error = false;
 
-	if(!isUntranslated() && _msgid.first().contains(reg))
+	if(!isUntranslated() && d->_msgid.first().contains(reg))
 	{
-        if(neededLines <= 0 || _msgstr.first().contains(reg))
+        if(neededLines <= 0 || d->_msgstr.first().contains(reg))
         {
     		error = true;
         }
-        else if( _msgstr.first().contains(QString("\\n"))+1 != neededLines )
+        else if( d->_msgstr.first().contains(QString("\\n"))+1 != neededLines )
         {
             error = true;
         }
@@ -581,11 +685,38 @@ bool CatalogItem::checkSingularPlural(const QRegExp& reg, const int neededLines)
 	
 	if(error)
 	{
-		_error = _error | SingularPlural;
+		d->_error = d->_error | SingularPlural;
 	}
 	else
 	{
-		_error = _error & ~SingularPlural;
+		d->_error = d->_error & ~SingularPlural;
+	}
+
+	return !error;
+}
+
+
+
+bool CatalogItem::checkXmlTags()
+{
+	bool error = false;
+
+	if(!isUntranslated())
+	{
+		QString text = msgstr(true);
+		QDomDocument doc;
+
+		text.replace( QRegExp( "\\\\\"" ), "\"" ); // Change '\"' to '"'
+		error = ! doc.setContent("<para>" + text + "</para>" );
+	}
+
+	if(error)
+	{
+		d->_error = d->_error | XmlTags;
+	}
+	else
+	{
+		d->_error = d->_error & ~XmlTags;
 	}
 
 	return !error;
@@ -596,7 +727,7 @@ bool CatalogItem::checkSingularPlural(const QRegExp& reg, const int neededLines)
 int CatalogItem::checkErrors(QChar accelMarker,const QRegExp& contextInfo
         , const QRegExp& singularPlural, const int neededLines)
 {
-	_error=None;
+	d->_error=None;
 
 	checkArgs(contextInfo);
 	checkAccelerator(accelMarker, contextInfo);
@@ -604,7 +735,7 @@ int CatalogItem::checkErrors(QChar accelMarker,const QRegExp& contextInfo
 	checkForContext(contextInfo);
     checkSingularPlural(singularPlural,neededLines);
 
-	return _error;
+	return d->_error;
 }
 
 QString CatalogItem::asString()
@@ -637,7 +768,7 @@ void CatalogItem::write(QTextStream& stream) const
       stream << "\"" << (*lit) << "\"\n";
    }
 
-   if(_gettextPluralForm)
+   if(d->_gettextPluralForm)
    {
        list = msgidAsList(true);
        // if the msgid has more than one line
@@ -651,7 +782,7 @@ void CatalogItem::write(QTextStream& stream) const
        }
    }
 
-   if(!_gettextPluralForm)
+   if(!d->_gettextPluralForm)
    {
        list=msgstrAsList();
        // if the msgstr has more than one line
@@ -666,7 +797,7 @@ void CatalogItem::write(QTextStream& stream) const
    }
    else
    {
-       int forms = _msgstr.count();
+       int forms = d->_msgstr.count();
        for(int i=0; i<forms; i++)
        {
            list=msgstrAsList(i);
@@ -690,14 +821,14 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
 
    clear();
 
-   _valid=false;
+   d->_valid=false;
 
    QString line;
    bool cancelLoop=false;
    bool error=false;
    bool recoverableError=false;
    bool obsolete=false;
-   QStringList::Iterator msgstrIt=_msgstr.begin();
+   QStringList::Iterator msgstrIt=d->_msgstr.begin();
    
    while(!stream.eof() && !cancelLoop)
    {
@@ -720,12 +851,12 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
            {
               obsolete=true;
 	      part=Comment;
-	      _comment=line;
+	      d->_comment=line;
            }
            else if(line.contains(QRegExp("^#")))
            {
                part=Comment;
-               _comment=line;
+               d->_comment=line;
            }
            else if(line.contains(QRegExp("^msgid\\s*\".*\"$")))
            {
@@ -735,7 +866,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
                line.replace(QRegExp("^msgid\\s*\""),"");
                line.replace(QRegExp("\"$"),"");
 
-               (*_msgid.begin())=line;
+               (*(d->_msgid).begin())=line;
            }
 		     // one of the quotation marks is missing
            else if(line.contains(QRegExp("^msgid\\s*\"?.*\"?$")))
@@ -746,7 +877,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
                line.replace(QRegExp("^msgid\\s*\"?"),"");
                line.replace(QRegExp("\"$"),"");
 
-               (*_msgid.begin())=line;
+               (*(d->_msgid).begin())=line;
 
 			   if(!line.isEmpty())
 			       recoverableError=true;
@@ -766,12 +897,12 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
 	       continue;
             else if(line.contains(QRegExp("^#~")))
             {
-               _comment+=("\n"+line);
+               d->_comment+=("\n"+line);
 	       obsolete=true;
             }
             else if(line.contains(QRegExp("^#")))
             {
-               _comment+=("\n"+line);
+               d->_comment+=("\n"+line);
             }
             else if(line.contains(QRegExp("^msgid\\s*\".*\"$")))
             {
@@ -781,7 +912,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
                line.replace(QRegExp("^msgid\\s*\""),"");
                line.replace(QRegExp("\"$"),"");
 
-               (*_msgid.begin())=line;
+               (*(d->_msgid).begin())=line;
             }
 			// one of the quotation marks is missing
 			else if(line.contains(QRegExp("^msgid\\s*\"?.*\"?$")))
@@ -792,14 +923,14 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
                line.replace(QRegExp("^msgid\\s*\"?"),"");
                line.replace(QRegExp("\"$"),"");
 
-               (*_msgid.begin())=line;
+               (*(d->_msgid).begin())=line;
 			   
 			   if(!line.isEmpty())
 			       recoverableError=true;
             }
             else
             {
-               kdDebug(KBABEL) << "no comment or msgid found after a comment while parsing: " << _comment << endl;
+               kdDebug(KBABEL) << "no comment or msgid found after a comment while parsing: " << d->_comment << endl;
 
                error=true;
                cancelLoop=true;
@@ -816,10 +947,10 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
                line.replace(QRegExp("\"$"),"");
 
                QStringList::Iterator it;
-               if(_gettextPluralForm)
-                   it = _msgid.fromLast();
+               if(d->_gettextPluralForm)
+                   it = d->_msgid.fromLast();
                else
-                   it = _msgid.begin();
+                   it = d->_msgid.begin();
                
                // add Msgid line to item
                if((*it).isEmpty())
@@ -830,30 +961,30 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
             else if(line.contains(QRegExp("^msgid_plural\\s*\".*\"$")))
             {
                part=Msgid;
-               _gettextPluralForm = true;
+               d->_gettextPluralForm = true;
 
                // remove quotes at beginning and the end of the lines
                line.replace(QRegExp("^msgid_plural\\s*\""),"");
                line.replace(QRegExp("\"$"),"");
 
-               _msgid.append(line);
+               d->_msgid.append(line);
             }
 			// one of the quotation marks is missing
 			else if(line.contains(QRegExp("^msgid_plural\\s*\"?.*\"?$")))
             {
                part=Msgid;
-               _gettextPluralForm = true;
+               d->_gettextPluralForm = true;
 
                // remove quotes at beginning and the end of the lines
                line.replace(QRegExp("^msgid_plural\\s*\"?"),"");
                line.replace(QRegExp("\"$"),"");
 
-               _msgid.append(line);
+               d->_msgid.append(line);
 			   
                if(!line.isEmpty())
 			       recoverableError=true;
             }
-           else if(!_gettextPluralForm 
+           else if(!d->_gettextPluralForm 
                    && line.contains(QRegExp("^msgstr\\s*\".*\\n?\"$")))
             {
                part=Msgstr;
@@ -864,7 +995,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
 
                (*msgstrIt)=line;
             }
-			else if(!_gettextPluralForm
+			else if(!d->_gettextPluralForm
                     && line.contains(QRegExp("^msgstr\\s*\"?.*\\n?\"?$")))
             {
                part=Msgstr;
@@ -878,7 +1009,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
 			   if(!line.isEmpty())
 			       recoverableError=true;
             }
-            else if(_gettextPluralForm 
+            else if(d->_gettextPluralForm 
                     && line.contains(QRegExp("^msgstr\\[0\\]\\s*\".*\\n?\"$")))
             {
                part=Msgstr;
@@ -889,7 +1020,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
 
                (*msgstrIt)=line;
             }
-			else if(_gettextPluralForm 
+			else if(d->_gettextPluralForm 
                     && line.contains(QRegExp("^msgstr\\[0\\]\\s*\"?.*\\n?\"?$")))
             {
                part=Msgstr;
@@ -906,7 +1037,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
  
             else if(line.contains(QRegExp("^#")) || line.contains(QRegExp("^msgid")))
             {
-               kdDebug(KBABEL) << "no msgstr or msgid found after a msgid while parsing: " << _msgid.first() << endl;
+               kdDebug(KBABEL) << "no msgstr or msgid found after a msgid while parsing: " << d->_msgid.first() << endl;
 
                cancelLoop=true;
                error=true;
@@ -921,10 +1052,10 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
                line.replace(QRegExp("\"$"),"");
 
                QStringList::Iterator it;
-               if(_gettextPluralForm)
-                   it = _msgid.fromLast();
+               if(d->_gettextPluralForm)
+                   it = d->_msgid.fromLast();
                else
-                   it = _msgid.begin();
+                   it = d->_msgid.begin();
                
                // add Msgid line to item
                if((*it).isEmpty())
@@ -934,7 +1065,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
             }
             else
             {
-               kdDebug(KBABEL) << "no msgstr or msgid found after a msgid while parsing: " << _msgid.first() << endl;
+               kdDebug(KBABEL) << "no msgstr or msgid found after a msgid while parsing: " << d->_msgid.first() << endl;
 
                cancelLoop=true;
                error=true;
@@ -956,23 +1087,23 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
                else
                   (*msgstrIt)+=("\n"+line);
             }
-            else if(_gettextPluralForm 
+            else if(d->_gettextPluralForm 
                     && line.contains(QRegExp("^msgstr\\[[0-9]+\\]\\s*\".*\\n?\"$")))
             {
                // remove quotes at beginning and the end of the lines
                line.replace(QRegExp("^msgstr\\[[0-9]+\\]\\s*\"?"),"");
                line.replace(QRegExp("\"$"),"");
 
-               msgstrIt=_msgstr.append(line);
+               msgstrIt=d->_msgstr.append(line);
             }
-			else if(_gettextPluralForm 
+			else if(d->_gettextPluralForm 
                     && line.contains(QRegExp("^msgstr\\[[0-9]\\]\\s*\"?.*\\n?\"?$")))
             {
                // remove quotes at beginning and the end of the lines
                line.replace(QRegExp("^msgstr\\[[0-9]\\]\\s*\"?"),"");
                line.replace(QRegExp("\"$"),"");
 
-               msgstrIt=_msgstr.append(line);
+               msgstrIt=d->_msgstr.append(line);
 
 			   if(!line.isEmpty())
 			       recoverableError=true;
@@ -985,7 +1116,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
             }
             else if(line.contains(QRegExp("^msgstr")))
             {
-               kdDebug(KBABEL) << "no msgid or comment found after a msgstr while parsing: " << _msgstr.last() << endl;
+               kdDebug(KBABEL) << "no msgid or comment found after a msgstr while parsing: " << d->_msgstr.last() << endl;
 
                cancelLoop=true;
                error=true;
@@ -1006,7 +1137,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
             }
             else
             {
-               kdDebug(KBABEL) << "no msgid or comment found after a msgstr while parsing: " << _msgstr.last() << endl;
+               kdDebug(KBABEL) << "no msgid or comment found after a msgstr while parsing: " << d->_msgstr.last() << endl;
 
                cancelLoop=true;
                error=true;
@@ -1034,7 +1165,7 @@ CatalogItem::IOStatus CatalogItem::read(QTextStream& stream)
 		return RecoveredParseError;
     else
     {
-      _valid=true;
+      d->_valid=true;
       return obsolete ? Obsolete : Ok;
     }
 }
@@ -1044,14 +1175,14 @@ CatalogItem::IOStatus CatalogItem::fastRead(FlexLexer *lexer, QTextCodec *codec,
 {
    clear();
 
-   _valid=false;
+   d->_valid=false;
 
     // comment
     if( lastToken == T_COMMENT )
     {
-	_comment = codec->toUnicode(lexer->YYText());
+	d->_comment = codec->toUnicode(lexer->YYText());
 	while( lexer->yylex() == T_COMMENT )
-	    _comment += "\n"+codec->toUnicode(lexer->YYText());
+	    d->_comment += "\n"+codec->toUnicode(lexer->YYText());
 //	kdDebug() << "Comment: " << _comment << endl;
     }
 
@@ -1065,7 +1196,7 @@ CatalogItem::IOStatus CatalogItem::fastRead(FlexLexer *lexer, QTextCodec *codec,
     if( lastToken != T_MSGID ) return ParseError;
     
     if( lexer->yylex() != T_STRING ) return ParseError;
-    QStringList::Iterator it = _msgid.begin();
+    QStringList::Iterator it = d->_msgid.begin();
     *it = codec->toUnicode(lexer->YYText());
     if( storeText )
 	while( lexer->yylex() == T_STRING )
@@ -1082,9 +1213,9 @@ CatalogItem::IOStatus CatalogItem::fastRead(FlexLexer *lexer, QTextCodec *codec,
 
     if( lastToken == T_MSGIDPLURAL ) 
     {
-	_gettextPluralForm = true;
+	d->_gettextPluralForm = true;
 	if( lexer->yylex() != T_STRING ) return ParseError;
-	it = _msgid.fromLast();
+	it = d->_msgid.fromLast();
 	*it = codec->toUnicode(lexer->YYText());
 	if( storeText ) 
 	    while( lexer->yylex() == T_STRING )
@@ -1096,10 +1227,10 @@ CatalogItem::IOStatus CatalogItem::fastRead(FlexLexer *lexer, QTextCodec *codec,
     // msgstr
     if( lastToken != T_MSGSTR ) return ParseError;
 
-    if( !_gettextPluralForm )
+    if( !d->_gettextPluralForm )
     {
 	if( lexer->yylex() != T_STRING ) return ParseError;
-	it = _msgstr.begin();
+	it = d->_msgstr.begin();
 	*it = codec->toUnicode(lexer->YYText());
 	if( storeText || msgid().isEmpty() ) // if we should store the text or it is a header
 	    while( lexer->yylex() == T_STRING )
@@ -1118,7 +1249,7 @@ CatalogItem::IOStatus CatalogItem::fastRead(FlexLexer *lexer, QTextCodec *codec,
 	while( lastToken == T_MSGSTR && s.contains( QRegExp("^msgstr\\[[0-9]+\\]" ) ) )
 	{
 	    if( lexer->yylex() != T_STRING ) return ParseError;
-	    it = _msgstr.fromLast();
+	    it = d->_msgstr.fromLast();
 	    *it = codec->toUnicode(lexer->YYText());
 	    
 	    if( storeText )
@@ -1131,7 +1262,16 @@ CatalogItem::IOStatus CatalogItem::fastRead(FlexLexer *lexer, QTextCodec *codec,
 	} 
     }
     
-     _valid=true;
+     d->_valid=true;
     return Ok;
 }
 
+void CatalogItem::operator=(const CatalogItem& rhs)
+{
+    d->_comment = rhs.d->_comment;
+    d->_msgid = rhs.d->_msgid;
+    d->_msgstr = rhs.d->_msgstr;
+    d->_valid = rhs.d->_valid;
+    d->_error = rhs.d->_error;
+    d->_gettextPluralForm = rhs.d->_gettextPluralForm;    
+}
