@@ -23,12 +23,14 @@
 #define CATALOGITEM_H
 
 #include <qstringlist.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 class QTextStream;
 class FlexLexer;
 class EditCommand;
 
+class CatalogItemPrivate;
+
 /**
 * This class represents an entry in a catalog.
 * It contains the comment, the Msgid and the Msgstr.
@@ -51,12 +53,15 @@ public:
 	 * @see checkEquation
 	 * @see checkContext
      * @see checkSingularPlural
+         * @see checkXmlTags
 	 */
 	enum Error{None=0, Syntax=1, Args=2, Accel=4, Equation=8, Context=16
-        , SingularPlural=32};
+        , SingularPlural=32, XmlTags=64};
 
     /** Constructor */
     CatalogItem();
+    /** Copy constructor */
+    CatalogItem(const CatalogItem&);
     /** Constructs a catalogitem from a string*/
     CatalogItem(QString item);
     /** Destructor */
@@ -76,6 +81,10 @@ public:
     */
     bool isCformat() const;
     /**
+    * returns true, if the string ", no=c-format" is contained in the comment
+    */
+    bool isNoCformat() const;
+    /**
     * returns true, if the Msgid is untranslated, this means the
     * Msgstr is empty
     */
@@ -86,7 +95,7 @@ public:
      */
     bool isPluralForm() const;
 
-    bool isValid() const {return _valid;}
+    bool isValid() const;
 
 	void setSyntaxError(bool);
 
@@ -115,9 +124,9 @@ public:
     /** returns the comment of this entry */
     QString comment() const;
     /** returns the msgid of the entry */
-    QString msgid() const;
+    QString msgid(const bool noNewlines = false) const;
     /** returns the msgstr of the entry */
-    QString msgstr() const;
+    QString msgstr(const bool noNewlines = false) const;
 
     /**
      * @param plural If this is true and the item is a gettext plural
@@ -134,9 +143,9 @@ public:
     QStringList msgstrAsList(int pluralNr=0) const;
     QStringList commentAsList() const;
 
-    void setComment(QString com){_comment=com;}
-    void setMsgid(QString msg){_msgid=msg;}
-    void setMsgstr(QString msg){_msgstr=msg;}
+    void setComment(QString com);
+    void setMsgid(QString msg);
+    void setMsgstr(QString msg);
 
     void processCommand(EditCommand* cmd, bool undo=false);
 
@@ -145,7 +154,10 @@ public:
     QString asString();
 
     /** @return a list of tags in the msgid */
-    const QStringList& tagList();
+    QStringList tagList();
+
+    /** @return a list of args in the msgid */
+    QStringList argList();
 
 	/** 
 	* checks, if number and type of arguments (%1, %s,...)
@@ -159,7 +171,7 @@ public:
 	* of accelMarker 
 	* @return false, if an error has been found
 	*/
-	bool checkAccelerator(QChar accelMarker,const QRegExp& comment);
+	bool checkAccelerator(QChar accelMarker, const QRegExp& comment);
 	
 	/**
 	* when the msgid is of the form abc=yxz it checks if abc is 
@@ -189,10 +201,17 @@ public:
      */
     bool checkSingularPlural( const QRegExp& reg, const int neededLines );
 	
+	/**
+	 * checks if the message is well-formed XML, by parsing it as a
+	 * paragraph. This is useful when translating KDE documentation.
+	 * @return false, if an error has been found
+	 */
+	bool checkXmlTags();
+
 	/**
 	 * @return the errors of this item. @see CatalogItem::Error
 	 */
-	int errors() const { return _error; }
+	int errors() const;
 
 	/**
 	 * makes some sanity checks and set status accordingly
@@ -233,27 +252,10 @@ public:
     */
     void write(QTextStream& stream) const;
 
-    void operator=(const CatalogItem& rhs) {
-	_comment = rhs._comment;
-	_msgid = rhs._msgid;
-	_msgstr = rhs._msgstr;
-	_valid = rhs._valid;
-    _error = rhs._error;
-    _gettextPluralForm = rhs._gettextPluralForm;
-    }
+    void operator=(const CatalogItem& rhs);
 
 private:
-   QString _comment;
-   QStringList _msgid;
-   QStringList _msgstr;
-
-   QStringList *_tagList;
-
-   bool _valid;
-   int _error;
-
-   /** flag, if this entry is a plural forms entry */
-   bool _gettextPluralForm;
+   CatalogItemPrivate* d;
 };
 
 #endif // CATALOGITEM_H
