@@ -277,7 +277,7 @@ void KBabel::init(KBCatalog* catalog)
             encodingStr=QTextCodec::codecForLocale()->name();
       }
       
-      if( KBabelSplash::_splashWidget ) KBabelSplash::_splashWidget->close(); //close splash screen window, if there is one
+      if( KBabelSplash::instance ) KBabelSplash::instance->close(); //close splash screen window, if there is one
 
       KMessageBox::information(0,i18n("You have not run KBabel before. "
 		   "To allow KBabel to work correctly you must enter some "
@@ -1014,6 +1014,9 @@ void KBabel::fileOpen()
 
 void KBabel::addToRecentFiles(KURL url)
 {
+    // do not allow invalid URLs
+    if( !url.isValid() || url.isEmpty() ) return;
+    
     KRecentFilesAction *recent;
     recent = (KRecentFilesAction*)actionCollection()->action(KStdAction::stdName(KStdAction::OpenRecent));
 
