@@ -3,6 +3,8 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
+		2002-2003  by Stanislav Visnovsky
+			    <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -243,6 +245,18 @@ void KBabelView::insertNextTag()
     } 
     else
     {
+	if( _catalog->msgid( _currentIndex ).startsWith("_n:") )
+	{
+	    int pos = msgstrEdit->currentIndex();
+    	    int currentFormBegin=s.findRev("\\n",pos);
+	    if( currentFormBegin == -1 ) currentFormBegin=0;
+	    else currentFormBegin+=3; // skip the newline
+	    int currentFormEnd=s.find("\\n",pos);
+	    if( currentFormEnd == -1 ) currentFormEnd=s.length();
+	
+	    s=s.mid(currentFormBegin,currentFormEnd-currentFormBegin);
+	}
+		
 	TagExtractor te(s);
 	uint num=te.countTags();
 	if(num >= _tags.count())
@@ -374,6 +388,18 @@ void KBabelView::insertNextArg()
 
     QString s = _catalog->msgstr(_currentIndex).left(offset);
     
+    if( _catalog->msgid( _currentIndex ).startsWith("_n:" ) )
+    {
+	int pos = msgstrEdit->currentIndex();
+    	int currentFormBegin=s.findRev("\\n",pos);
+	if( currentFormBegin == -1 ) currentFormBegin=0;
+	else currentFormBegin+=3; // skip the newline
+	int currentFormEnd=s.find("\\n",pos);
+	if( currentFormEnd == -1 ) currentFormEnd=s.length();
+	
+	s=s.mid(currentFormBegin,currentFormEnd-currentFormBegin);
+    }
+    
     ArgExtractor te(s);
     uint num=te.countArgs();
     if(num >= _args.count())
