@@ -22,12 +22,6 @@
 #ifndef KBCATALOG_H
 #define KBCATALOG_H
 
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-
 #include "catalog.h"
 
 class HeaderEditor;
@@ -43,7 +37,7 @@ class KBCatalog : public Catalog
     Q_OBJECT
 
 public:
-   KBCatalog(QObject* parent=0, const char* name=0);
+   KBCatalog(QString configFile = QString::null ,QObject* parent=0, const char* name=0);
    virtual ~KBCatalog();
 
    HeaderEditor* headerEditor();
