@@ -454,6 +454,9 @@ void RoughTransDlg::slotUser1()
                 }
             }
             
+            // handle the last word as well
+            if( !word.isEmpty() ) wordList.append(word);
+
             dit = dictList.begin();
             int wordCounter=0;
             while(wordCounter==0 && dit != dictList.end())
