@@ -29,18 +29,41 @@
 #include <kconfig.h>
 #include <kstandarddirs.h>
 
+const bool Defaults::Editor::autoUnsetFuzzy=true;
+const bool Defaults::Editor::autoCheckArgs=true;
+const bool Defaults::Editor::autoCheckAccel=true;
+const bool Defaults::Editor::autoCheckEquation=true;
+const bool Defaults::Editor::autoCheckContext=true;
+const bool Defaults::Editor::autoCheckSingularPlural=true;
+const bool Defaults::Editor::autoCheckXmlTags=true;
+const bool Defaults::Editor::beepOnError=false;
+const bool Defaults::Editor::autoCheckColorError=true;
+
+const bool Defaults::Editor::cleverEditing=true;
+const bool Defaults::Editor::highlightBg=false;
+const bool Defaults::Editor::whitespacePoints=true;
+const bool Defaults::Editor::quotes=false;
+const bool Defaults::Editor::highlightSyntax=true;
+
+const bool Defaults::Editor::ledInStatusbar=false;
 
 const QColor Defaults::Editor::bgColor=QColor(255,255,192);
 const QColor Defaults::Editor::quotedColor=QColor(Qt::darkGreen);
 const QColor Defaults::Editor::errorColor=QColor(Qt::red);
 const QColor Defaults::Editor::cformatColor=QColor(Qt::blue);
 const QColor Defaults::Editor::accelColor=QColor(Qt::darkMagenta);
+const QColor Defaults::Editor::tagColor=QColor(Qt::darkBlue);
 const QColor Defaults::Editor::ledColor=QColor(Qt::red);
 const QColor Defaults::Editor::diffAddColor=QColor(192,192,255);
 const QColor Defaults::Editor::diffDelColor=QColor(255,128,128);
 QString Defaults::Editor::_ignoreURL=QString::null;
 const QString Defaults::Editor::diffBaseDir=QString::null;
 
+const bool Defaults::Editor::rememberIgnored=true;
+const bool Defaults::Editor::diffAddUnderline=false;
+const bool Defaults::Editor::diffDelStrikeOut=false;
+const bool Defaults::Editor::useDBForDiff=false;
+
 QFont Defaults::Editor::msgFont()
 {
    return KGlobalSettings::generalFont();
@@ -64,6 +87,7 @@ QString Defaults::Editor::ignoreURL()
 }
 
 const QString Defaults::Search::defaultModule="pocompendium";
+const bool Defaults::Search::autoSearch=false;
 
 QString Defaults::CatalogManager::poBaseDir()
 {
@@ -129,3 +153,6 @@ QStringList Defaults::CatalogManager::fileCommandNames()
 QString Defaults::CatalogManager::_poBaseDir=QString::null;
 QString Defaults::CatalogManager::_potBaseDir=QString::null;
 
+const bool Defaults::CatalogManager::openWindow=false;
+const bool Defaults::CatalogManager::killCmdOnExit=true;
+
