@@ -12,6 +12,7 @@
 
   Copyright  2000
   Andrea Rizzi rizzi@kde.org
+  Copyright 2003 Stanislav Visnovsky visnovsky@kde.org
 
   License GPL v 2.0
 
@@ -20,16 +21,14 @@
 #include <kdebug.h>
 #include <string.h>
 #include "database.h"
+#include <unistd.h>
 
-#if	DB_VERSION_MAJOR == 2 && DB_VERSION_MINOR >= 6 && DB_VERSION_PATCH >= 4
-#define DB_NEWER_264
-#endif
-#if	DB_VERSION_MAJOR == 2 && DB_VERSION_MINOR >= 7
-#define DB_NEWER_264
-#endif
-
+#include <qfile.h>
 
+#include <ktempfile.h>
+#include <kio/netaccess.h>
 
+#define KBABEL_SEARCH	8107
 
 WordItem::WordItem(char *data,QString w)
 {
@@ -38,7 +37,7 @@ word=w;
 count=*(uint32 *)data;
 
 data+=4;
-score=*(int *)data;
+//score=*(int *)data;
 data+=4;
 
 
@@ -82,7 +81,7 @@ return (score==-1);
 InfoItem::InfoItem()
 {
   catalogName="No catalog";  
-  lastTranslator="No tranlsator";
+  lastTranslator="No translator";
   lastFullPath="";
   charset="No charset";
   language="No language";
@@ -152,7 +151,27 @@ _size+=strlen(lastFullPath.utf8());
 return _size;
 }
 
-
+// this is a quick hack to copy a local file
+int copy_hack( QFile& input, QFile& output )
+{
+    if( !input.isOpen() ) {
+	if( ! input.open( IO_ReadOnly ) ) return -1;
+    }
+    
+    if( !output.isOpen() ) {
+	if( ! output.open( IO_WriteOnly ) ) return -1;
+    }
+    
+    char buffer[10240];
+    int s = 0;
+    while( !input.atEnd() ) {
+        s = input.readBlock(buffer, 10240);
+        output.writeBlock(buffer, s);
+    }
+    output.close();
+    input.close();
+    return 0;
+}
 
 DataBaseItem::DataBaseItem()
 {
@@ -257,7 +276,7 @@ QString filename;
 language=lang;
 iAmOk=true;
 basedir=directory;
-
+ indexDb = wordDb = infoDb = db = 0;
 openDataBase();
 
 
@@ -265,49 +284,175 @@ openDataBase();
 
 void DataBaseManager::openDataBase()
 {
-QString filename,directory;
+kdDebug() << "Opendatabase" << endl;
+QString directory;
 directory=basedir;
 QString ll="."+language;
 if(ll==".") ll=".NOLANG";
-filename="%1/translations%2.db";
-filename=filename.arg(directory).arg(ll);
 
-db=0;
+QString transfilename="%1/translations%2.db";
+transfilename=transfilename.arg(directory).arg(ll);
+
+QString infofilename="%1/catalogsinfo%2.db";
+infofilename=infofilename.arg(directory).arg(ll);
+
+QString wordsfilename="%1/wordsindex%2.db";
+wordsfilename=wordsfilename.arg(directory).arg(ll);
+
+QString keysfilename="%1/keysindex%2.db";
+keysfilename=keysfilename.arg(directory).arg(ll);
+
 cursor=0;
 int ret;
 
-ret=db_open(filename.local8Bit(),DB_BTREE,0,0644,0,0,&db);
-if(ret!=0)
- {
-  iAmOk=false;
-  emit cannotOpenDB(ret);
-  //Process error here.
- }
+ if (!db)
+     db_create( &db, 0, 0);
 
+ db_create(&infoDb, 0, 0);
+ db_create(&wordDb, 0, 0);
+ db_create(&indexDb,0, 0);
 
+ ret=db->open(db,
+#if DB_VERSION_MINOR > 0
+              NULL,
+#endif
+              transfilename.local8Bit(), 0, DB_BTREE, 0,0644);
+
+ if( ret == DB_OLD_VERSION ) {
+    kdDebug(KBABEL_SEARCH) << "Trying upgrade" << endl;
+    // try upgrade
+    
+    KTempFile transFile, infoFile, keysFile, wordsFile;
+    
+    // do the upgrade on the translation file
+    QFile transfilenameFile( transfilename );
+    
+    if( (ret = copy_hack( transfilenameFile , *transFile.file())) == 0 ) { 
+        ret = db->upgrade( db, transFile.name().local8Bit(), 0 );
+    }
+    
+    if( ret!= 0 ) {
+	kdDebug(KBABEL_SEARCH) << "Cannot upgrade translations, " << ret << endl;
+	// cleanup
+	transFile.unlink();
+	iAmOk=false;
+	emit cannotOpenDB(ret);
+	return ;
+    }
+    
+    // do the upgrade on the info file
+    QFile infofilenameFile( infofilename );
+    if( (ret = copy_hack( infofilenameFile , *infoFile.file())) == 0 ) { 
+        ret = infoDb->upgrade( infoDb, infoFile.name().local8Bit(), 0 );
+    }
+    
+    if( ret!= 0 ) {
+	kdDebug(KBABEL_SEARCH) << "Cannot upgrade catalogsinfo" << endl;
+	// cleanup
+	transFile.unlink();
+	infoFile.unlink();
+	iAmOk=false;
+	emit cannotOpenDB(ret);
+	return ;
+    }
+    
+    // do the upgrade on the words file
+    QFile wordfilenameFile( wordsfilename );
+    if( (ret = copy_hack( wordfilenameFile , *wordsFile.file())) == 0 ) { 
+        ret = wordDb->upgrade( wordDb, wordsFile.name().local8Bit(), 0 );
+    }
+    
+    if( ret!= 0 ) {
+	kdDebug(KBABEL_SEARCH) << "Cannot upgrade words" << endl;
+	// cleanup
+	transFile.unlink();
+	infoFile.unlink();
+	wordsFile.unlink();
+	iAmOk=false;
+	emit cannotOpenDB(ret);
+	return ;
+    }
+    
+    // do the upgrade on the keys file
+    QFile keysfilenameFile( keysfilename );
+    if( (ret = copy_hack( keysfilenameFile , *keysFile.file())) == 0 ) { 
+        ret = indexDb->upgrade( indexDb, keysFile.name().local8Bit(), 0 );
+    }
+    
+    if( ret!= 0 ) {
+	kdDebug(KBABEL_SEARCH) << "Cannot upgrade keys" << endl;
+	// cleanup
+	transFile.unlink();
+	infoFile.unlink();
+	wordsFile.unlink();
+	keysFile.unlink();
+	iAmOk=false;
+	emit cannotOpenDB(ret);
+	return ;
+    }
+    
+    kdDebug(KBABEL_SEARCH) << "Files upgraded, copying" << endl;
+    // use temporary file instead
+    if( ret==0 ) {
+	KIO::NetAccess::del( transfilename );
+	copy_hack( *transFile.file(), transfilenameFile );
+	transFile.unlink();
+
+	KIO::NetAccess::del( infofilename );
+	copy_hack( *infoFile.file(), infofilenameFile );
+	infoFile.unlink();
+	
+	KIO::NetAccess::del( wordsfilename );
+	copy_hack( *wordsFile.file(), wordfilenameFile );
+	wordsFile.unlink();
+
+	KIO::NetAccess::del( keysfilename );
+	copy_hack( *keysFile.file(), keysfilenameFile );
+	keysFile.unlink();
+
+	ret = db->open(db,
+#if DB_VERSION_MINOR > 0
+                       NULL,
+#endif
+                       transfilename.local8Bit(), 0, DB_BTREE, 0,0644);
+	if( ret != 0 ) {
+	    kdWarning(KBABEL_SEARCH) << "transFilename database can't be opened." << endl;
+	    kdWarning(KBABEL_SEARCH) << "Please, report this incident and how to reproduce it to kbabel@kde.org." << endl;
+	    iAmOk=false;
+	    emit cannotOpenDB(ret);
+	    return;
+	}
+
+    }
+    kdDebug(KBABEL_SEARCH) << "Upgrade done OK" << endl;
+}
 
 // Open catalogs information database
 
 
-filename="%1/catalogsinfo%2.db";
-filename=filename.arg(directory).arg(ll);
-ret=db_open(filename.local8Bit(),DB_RECNO,0,0644,0,0,&infoDb);
+
+ret=infoDb->open(infoDb,
+#if DB_VERSION_MINOR > 0
+              NULL,
+#endif
+                 infofilename.local8Bit(), 0, DB_RECNO, 0,0644);
 if(ret!=0)
  {
   iAmOk=false;
   emit cannotOpenDB(ret);
   //Process error here.
  }
-  else
-  loadInfo();  
+  else loadInfo();  
 
 
 
 // Words index database
 
-filename="%1/wordsindex%2.db";
-filename=filename.arg(directory).arg(ll);
-ret=db_open(filename.local8Bit(),DB_BTREE,0,0644,0,0,&wordDb);
+ret=wordDb->open(wordDb,
+#if DB_VERSION_MINOR > 0
+                 NULL,
+#endif
+                 wordsfilename.local8Bit(), 0, DB_BTREE, 0,0644);
 if(ret!=0)
  {
   iAmOk=false;
@@ -317,9 +462,11 @@ if(ret!=0)
 
 //Index of keys.
 
-filename="%1/keysindex%2.db";
-filename=filename.arg(directory).arg(ll);
-ret=db_open(filename.local8Bit(),DB_RECNO,0,0644,0,0,&indexDb);
+ret=indexDb->open(indexDb,
+#if DB_VERSION_MINOR > 0
+                  NULL,
+#endif
+                  keysfilename.local8Bit(), 0, DB_RECNO,0,0644);
 if(ret!=0)
  {
    iAmOk=false;
@@ -345,6 +492,9 @@ if(iAmOk) {
   indexDb->sync(indexDb,0);
   indexDb->close(indexDb,0);
     
+  // can not be opened again
+  indexDb = wordDb = infoDb = db = 0;
+
   }
  
 }
@@ -482,12 +632,7 @@ DataBaseItem DataBaseManager::cursorGet(uint32 flags)
  memset(&data,0,sizeof(DBT));
 
  if(cursor==0) 
-#ifdef DB_NEWER_264
   re=db->cursor(db,0,&cursor,0); 
-#else
-  re=db->cursor(db,0,&cursor); 
-#endif
-
 
  int ret;
  if((ret=cursor->c_get(cursor,&key,&data,flags))==0)
@@ -527,9 +672,9 @@ return iAmOk;
 
 int DataBaseManager::count()
 {
- DB_BTREE_STAT * dstat;
- db->stat(db,&dstat,0,DB_RECORDCOUNT);
- int ret=dstat->bt_nrecs;
+ DB_BTREE_STAT * dstat = 0;
+ db->stat(db,&dstat,DB_FAST_STAT);
+ int ret=dstat->bt_nkeys;
  free(dstat);
 
  return ret; 
@@ -545,11 +690,7 @@ int DataBaseManager::current()
  memset(&data,0,sizeof(DBT));
  
  if(cursor!=0)
-#ifdef DB_NEWER_264
   db->cursor(db,0,&cursor,0); 
-#else
-  db->cursor(db,0,&cursor); 
-#endif
  cursor->c_get(cursor,&key,&data,DB_GET_RECNO);
  return *(uint32 *)(data.data);
 
@@ -564,26 +705,44 @@ if(ll==".") ll=".NOLANG";
 filename="%1/translations%2.db";
 filename=filename.arg(directory).arg(ll);
 
+rename(filename.local8Bit(),filename.local8Bit()+",old");
+
 //kdDebug(0) << QString("Creating %1").arg(filename) << endl;
 
 iAmOk=true;
 
 int ret;
-DB_INFO di;
-memset(&di,0,sizeof(DB_INFO));
-di.flags=DB_RECNUM;
-ret=db_open(filename.local8Bit(),DB_BTREE,DB_CREATE,mode,0,&di,&db);
-if(ret!=0)
- iAmOk=false;
 
+ if (!db) {
+     if (db_create( &db, 0, 0) != 0) {
+         qDebug("db_create db failed");
+         iAmOk = false;
+         return false;
+     }
+ }
+
+db->set_flags(db, DB_RECNUM);
+ret=db->open(db,
+#if DB_VERSION_MINOR > 0
+             NULL,
+#endif
+             filename.local8Bit(),0, DB_BTREE, DB_CREATE|DB_EXCL, mode);
+ if(ret!=0) {
+     qDebug("db->open %s %d failed", filename.latin1(), mode);
+     iAmOk=false;
+ }
 
 
 filename="%1/catalogsinfo%2.db";
 filename=filename.arg(directory).arg(ll);
+rename(filename.local8Bit(),filename.local8Bit()+",old");
 
-memset(&di,0,sizeof(DB_INFO));
-//di.flags=DB_RECNUM;
-ret=db_open(filename.local8Bit(),DB_RECNO,DB_CREATE,mode,0,&di,&infoDb);
+ db_create( &infoDb, 0, 0);
+ret=infoDb->open(infoDb,
+#if DB_VERSION_MINOR > 0
+                 NULL,
+#endif
+                 filename.local8Bit(),0, DB_RECNO, DB_CREATE,mode);
 if(ret!=0)
  iAmOk=false;
 
@@ -591,12 +750,14 @@ if(ret!=0)
 
 filename="%1/wordsindex%2.db";
 filename=filename.arg(directory).arg(ll);
+rename(filename.local8Bit(),filename.local8Bit()+",old");
 
-
-
-memset(&di,0,sizeof(DB_INFO));
-//di.flags=DB_RECNUM;
-ret=db_open(filename.local8Bit(),DB_BTREE,DB_CREATE,mode,0,&di,&wordDb);
+ db_create( &wordDb, 0, 0);
+ret=wordDb->open(wordDb,
+#if DB_VERSION_MINOR > 0
+                 NULL,
+#endif
+                 filename.local8Bit(), 0, DB_BTREE, DB_CREATE,mode);
 if(ret!=0)
  iAmOk=false;
 
@@ -604,10 +765,14 @@ if(ret!=0)
 
 filename="%1/keysindex%2.db";
 filename=filename.arg(directory).arg(ll);
+rename(filename.local8Bit(),filename.local8Bit()+",old");
  
-memset(&di,0,sizeof(DB_INFO));
-
-ret=db_open(filename.local8Bit(),DB_RECNO,DB_CREATE,mode,0,&di,&indexDb);
+db_create( &indexDb, 0, 0);
+ret=indexDb->open(indexDb,
+#if DB_VERSION_MINOR > 0
+                  NULL,
+#endif
+                  filename.local8Bit(),0, DB_RECNO, DB_CREATE, mode);
 if(ret!=0)
  iAmOk=false;
  
@@ -736,9 +901,9 @@ void  DataBaseManager::loadInfo()
  int nrec;
  DB_BTREE_STAT *stat;
 // memset(&stat,0,sizeof(DB_BTREE_STAT));
- if(infoDb->stat(infoDb,&stat,0,DB_RECORDCOUNT))
+ if(infoDb->stat(infoDb,&stat,DB_FAST_STAT))
   fprintf(stderr,"Cannot stat\n");
- nrec=stat->bt_nrecs;
+ nrec=stat->bt_nkeys;
 free(stat);
 
  info.clear();
@@ -865,7 +1030,7 @@ uint32 step=1;
 
 int antibounce=0;
 //d+=4;
-int score=d[1];
+//int score=d[1];
 //d+=4; 
 bool forward,end=false;
 
@@ -1014,10 +1179,11 @@ return true;
 }
 
 
-bool DataBaseManager::removeLocation(QString word, int location)
+bool DataBaseManager::removeLocation(QString /*word*/, int /*location*/)
 {
 
 //#warning TODO: REMOVE LOCATION
+return true;
 	
 }
 
@@ -1158,9 +1324,9 @@ int count=0;
    QString msgstr=tran;
 //   TranslationItem tr;
 //   DataBaseItem newItem=dbit;
-    int ref;
+//    int ref;
     bool found=false,foundTr=false,isThisOne=false;
-    int removed=0;
+//    int removed=0;
 
     QValueList<TranslationItem>::Iterator ittr; //,ittrb;
     bool rem=false;
@@ -1241,7 +1407,7 @@ return count;
 
 void DataBaseManager::rebuildIndexes()
 {
-  uint32 loc;
+//  uint32 loc;
 #if 0
 //Reset the 2 databases here.
 
