@@ -28,6 +28,7 @@
 #include <kinstance.h>
 #include <kio/netaccess.h>
 
+#include <qregexp.h>
 #include <qtextstream.h>
 #include <qtimer.h>
 
@@ -980,7 +981,7 @@ void PoCompendium::registerData()
     
     if(data->active())
     {
-        emit progressStarts(i18n("Loading po compendium"));
+        emit progressStarts(i18n("Loading PO compendium"));
     }
     
     connect(data, SIGNAL(progressStarts(const QString)), this
