@@ -13,9 +13,12 @@ class Bug
 {
 public:
     typedef QValueList<Bug> List;
+    typedef QValueList<int> BugMergeList;
 
-    enum Severity { Critical, Grave, Crash, Normal, WishList };
-    enum Status { Closed, Open };
+    enum Severity { SeverityUndefined, Critical, Grave, Major, Crash, Normal,
+                    Minor, Wishlist };
+    enum Status { StatusUndefined, Unconfirmed, New, Assigned, Reopened,
+                  Closed };
 
     Bug();
     Bug( BugImpl *impl );
@@ -23,17 +26,31 @@ public:
     Bug &operator=( const Bug &rhs );
     ~Bug();
 
+    static QString severityLabel( Severity s );
+    /**
+      Return string representation of severity. This function is symmetric to
+      stringToSeverity().
+    */
     static QString severityToString( Severity s );
-    static Severity stringToSeverity( const QString &s, bool *ok = 0 );
+    /**
+      Return severity code of string representation. This function is symmetric
+      to severityToString().
+    */
+    static Severity stringToSeverity( const QString &, bool *ok = 0 );
 
     static QValueList<Severity> severities();
 
     QString title() const;
+    void setTitle( QString title );
     Person submitter() const;
     QString number() const;
     uint age() const;
     Severity severity() const;
+    void setSeverity( Severity severity );
     QString severityAsString() const;
+    Person developerTODO() const;
+           
+    BugMergeList mergedWith() const;
 
     /**
      * Status of a bug. Currently open or closed.
@@ -41,9 +58,18 @@ public:
      */
     Status status() const;
     void setStatus( Status newStatus );
-    
+
+    static QString statusLabel( Status s );
+    /**
+      Return string representation of status. This function is symmetric to
+      stringToStatus().
+    */
     static QString statusToString( Status s );
-    static Status stringToStatus( const QString &s, bool *ok = 0 );
+    /**
+      Return status code of string representation. This function is symmetric
+      to statusToString().
+    */
+    static Status stringToStatus( const QString &, bool *ok = 0 );
 
     bool operator==( const Bug &rhs );
     bool operator<( const Bug &rhs ) const;
