@@ -14,6 +14,10 @@ class BugDetails
 {
 public:
     typedef QValueList<BugDetails> List;
+    struct Attachment {
+        QByteArray contents;
+        QString filename;
+    };
 
     BugDetails();
     BugDetails( BugDetailsImpl *impl );
@@ -26,6 +30,8 @@ public:
     QString compiler() const;
     QString os() const;
     BugDetailsPart::List parts() const;
+    QValueList<BugDetails::Attachment> extractAttachments() const;
+    static QValueList<BugDetails::Attachment> extractAttachments( const QString& text );
 
     bool operator==( const BugDetails &rhs );
 
