@@ -38,8 +38,7 @@ class PackageSelectDialog : public KDialogBase
     void setPackages( const Package::List &pkgs );
 
     Package selectedPackage();
-
-    static Package getPackage( QWidget *parent );
+    QString selectedComponent();
 
   protected slots:
     void slotOk();
@@ -52,6 +51,7 @@ class PackageSelectDialog : public KDialogBase
   private:
     Package::List mPackages;
     Package mSelectedPackage;
+    QString mSelectedComponent;
     
     QListView *mRecentList;
     PackageListView *mCompleteList;
