@@ -41,7 +41,7 @@ DiffPrefs::DiffPrefs( QWidget* parent ) : PrefsBase( parent )
 	layout->setMargin( KDialog::marginHint() );
 
 	// add diff modes
-	m_modeButtonGroup = new QVButtonGroup( i18n( "Output format" ), page );
+	m_modeButtonGroup = new QVButtonGroup( i18n( "Output Format" ), page );
 	layout->addWidget( m_modeButtonGroup );
 	m_modeButtonGroup->setMargin( KDialog::marginHint() );	
 
@@ -52,7 +52,7 @@ DiffPrefs::DiffPrefs( QWidget* parent ) : PrefsBase( parent )
 	radioButton = new QRadioButton( i18n( "Unified" ), m_modeButtonGroup );
 
 	// #lines of context (loc)
-	locGroupBox     = new QHGroupBox( i18n( "Lines of context" ), page );
+	locGroupBox     = new QHGroupBox( i18n( "Lines of Context" ), page );
 	layout->addWidget( locGroupBox );
 	locGroupBox->setMargin( KDialog::marginHint() );
 
@@ -85,12 +85,12 @@ DiffPrefs::DiffPrefs( QWidget* parent ) : PrefsBase( parent )
 
 	m_tabsCheckBox        = new QCheckBox( i18n( "&Expand tabs to spaces in output" ), moreOptionButtonGroup );
 	m_linesCheckBox       = new QCheckBox( i18n( "I&gnore added or removed empty lines" ), moreOptionButtonGroup );
-	m_whitespaceCheckBox  = new QCheckBox( i18n( "Ig&nore changes to the number of whitespaces in a line" ), moreOptionButtonGroup );
+	m_whitespaceCheckBox  = new QCheckBox( i18n( "Ig&nore changes in the amount of whitespace" ), moreOptionButtonGroup );
 
 	layout->addStretch( 1 );
 	page->setMinimumSize( sizeHintForWidget( page ) );
 
-	addTab( page, i18n( "&Options" ) );
+	addTab( page, i18n( "O&ptions" ) );
 };
 
 DiffPrefs::~DiffPrefs()
