@@ -16,6 +16,21 @@
 
 ; This file is maintained by David Faure <faure@kde.org>
 
+
+; Global variables used to differentiate between different emacs
+; versions :
+; emacs - t if GNU/Emacs is used
+; xemacs - t if XEmacs is being used
+
+(if (string= (substring (emacs-version) 0 6) "XEmacs")
+    (progn
+      (setq emacs nil)
+      (setq xemacs t))
+  (progn
+    (setq emacs t)
+    (setq xemacs nil)))
+
+
 ;; -------  First part, from Arnt's "c++ stuff"
 
 (defun agulbra-c++-tab (arg)
@@ -49,11 +64,17 @@
 
 ; the above used to contain (untabify (point-min) (point-max)) too
 
+;; it seems that recursion in agulbra-clean-out-spaces trashes Gnu/Emacs stack
+;; one of the functions in there has to behave differently than its XEmacs
+;; counterpart does, if you're reading this in a middle of may 2002 then
+;; please email me (Zack) at zackrat@att.net and bug me to finally fix this
 (defun agulbra-c++-clean-out-spaces ()
   "Remove spaces at ends of lines, only in c++ mode"
   (interactive)
   (and (eq major-mode 'c++-mode)
-       (agulbra-clean-out-spaces)))
+       (if xemacs 
+	   (agulbra-clean-out-spaces)
+  )))
 
 (add-hook 'find-file-hooks 'agulbra-c++-clean-out-spaces)
 (add-hook 'write-file-hooks 'agulbra-c++-clean-out-spaces)
@@ -209,7 +230,7 @@ With arg, to it arg times."
                              (concat class "::~" class "(")
                              t t function)
                             "\n{\n    \n}\n"))))
-                  ((string-match " *\\([a-z0-9_]+\\)[ \\t]*(" function)
+                  ((string-match " *\\([a-zA-Z0-9_]+\\)[ \\t]*(" function)
                    (progn
                      (setq insertion-string
                            (concat
@@ -1433,7 +1454,7 @@ With arg, to it arg times."
               QChildEvent QCustomEvent)
     (qdatetime.h QTime QDateTime QDate)
     
-    ; Qt/Embeded
+    ; Qt/Embedded
     (qcopchannel_qws.h QCopChannel)
     (qdirectpainter_qws.h QDirectPainter)
     (qfontfactorybdf_qws.h QFontFactoryBDF)
@@ -1467,8 +1488,12 @@ With arg, to it arg times."
     (qwsproperty_qws.h QWSPropertyManager)
     (qwsregionmanager_qws.h QWSRegionManager)
     (qwssocket_qws.h QWSSocket QWSServerSocket)
-    (qwswindowsdecoration_qws.h QWSWindowsDecoration))
-    "List of special include files which do not follow the normal scheme")
+    (qwswindowsdecoration_qws.h QWSWindowsDecoration)
+
+    ; KDE
+    (kdebug.h kdDebug kdWarning kdError kdFatal kdBacktrace)
+    
+    ) "List of special include files which do not follow the normal scheme")
 
 ;; Lookup class `cls' in kdab-special-includes and return the associate include file name
 (defun kdab-map-special (cls)
@@ -1512,7 +1537,6 @@ With arg, to it arg times."
                     ((kdab-map-special word) (kdab-map-special word))
                     ((string-match "^qdom" word) "qdom.h")
                     ((string-match "^qxml" word) "qxml.h")
-                    ((string-match "^kddebug" word) "kdebug.h")
                     (t (concat word ".h")))))
       (beginning-of-buffer)
       (if (not (re-search-forward (concat "#include *<" header ">") nil t))
@@ -1557,8 +1581,14 @@ With arg, to it arg times."
 ;;; definition by selecting it from the menu.  The following code turns this on
 ;;; for all of the recognized languages.  Scanning the buffer takes some time,
 ;;; but not much.
-(require 'func-menu)
-(add-hook 'find-file-hooks 'fume-add-menubar-entry)
+
+(if xemacs 
+    (progn
+      (require 'func-menu)
+      (add-hook 'find-file-hooks 'fume-add-menubar-entry) )
+  (progn
+    (require 'imenu)))
+    ;(add-hook 'find-file-hooks 'imenu)) )
 
 ;; Switch between the declaration of a class member in .cc/.cpp/.C, and its definition in the .h file
 ;; Written by David and Reggie after much hair tearing
@@ -1645,7 +1675,7 @@ With arg, to it arg times."
       (setq f (replace-match "_" t t f)))
     (save-excursion
       (goto-char (point-min))
-      (insert "#ifndef " f "\n#define " f "\n\n")
+      (insert "#ifndef " (upcase f) "\n#define " (upcase f) "\n\n")
       (goto-char (point-max))
       (insert "\n#endif\n")
       )
@@ -1752,10 +1782,14 @@ With arg, to it arg times."
 (put 'newline-and-indent 'pending-delete t)
 
 ; A wheel mouse that doesn't beep, unlike mwheel-install
-(defun scroll-me-up () (interactive) (scroll-up 3))
-(defun scroll-me-down () (interactive) (scroll-down 3))
+(defun scroll-me-up () (interactive) (scroll-up 4))
+(defun scroll-me-down () (interactive) (scroll-down 4))
+(defun scroll-me-up-a-bit () (interactive) (scroll-up 1))
+(defun scroll-me-down-a-bit () (interactive) (scroll-down 1))
 (define-key global-map [(button4)] 'scroll-me-down)
 (define-key global-map [(button5)] 'scroll-me-up)
+(define-key global-map [(shift button4)] 'scroll-me-down-a-bit)
+(define-key global-map [(shift button5)] 'scroll-me-up-a-bit)
 
 ; Compilation
 (defun makeclean () (interactive) (compile "make clean"))
@@ -1763,7 +1797,7 @@ With arg, to it arg times."
 (defun makeinstall () (interactive) (compile "make install"))
 (defun makeinstallexec () (interactive) (compile "make install-exec"))
 (defun makethisfile () (interactive)
-    (let ((f (buffer-file-name)))
+    (let ((f (buffer-name)))
       (if (string-match "\.cpp$" f) (setq f (replace-match "\.lo" t t f)))
       (if (string-match "\.cc$" f) (setq f (replace-match "\.lo" t t f)))
       (compile (concat "make " f ))))
@@ -1776,7 +1810,9 @@ With arg, to it arg times."
 
 ;; pc-like textmarking
 (load "pc-select")
-(pc-select-mode)
+(if xemacs
+    (pc-select-mode)
+  (pc-selection-mode))
 
 ; Move in other window
 (defun scroll-other-up () (interactive) (scroll-other-window-down 1)) ; hehe :)
@@ -1786,9 +1822,10 @@ With arg, to it arg times."
 
 ;; Some example bindings, feel free to customize :)
 (define-key global-map [(f2)] 'grep)
+;; FIXME: remember to get these two working on Gnu/Emacs (Zack)
 (define-key global-map [(f3)] 'fume-list-functions)
 (define-key global-map [(shift f3)] 'fume-prompt-function-goto)
-(define-key global-map '(shift button3) 'mouse-function-menu)
+(define-key global-map [(shift button3)] 'mouse-function-menu)
 (define-key global-map [(shift f4)] 'makeclean)
 (define-key global-map [(f4)] 'make)
 (define-key global-map [(f5)] 'makeinstall)
@@ -1796,12 +1833,22 @@ With arg, to it arg times."
 (define-key global-map [(shift f6)] 'makethisfile)
 (define-key global-map [(f6)] 'agulbra-switch-cpp-h)
 (define-key global-map [(f7)] 'switch-to-function-def)
-(define-key global-map 'f8 'function-menu)
+;; imenu does that interactively
+(if xemacs
+    (define-key global-map [(f8)] 'function-menu))
 ;(define-key global-map [(f9)] 'agulbra-make-member) ;; uncomment this for a killer feature
 (define-key global-map [(f10)] 'kdab-insert-header)
 (define-key global-map [(shift f10)] 'kdab-lookup-qt-documentation)
 (define-key global-map [(control meta d)] 'insert-kdDebug)
 
+; Standard Qt/KDE shortcuts: Ctrl+Backspace, Ctrl+Delete
+(define-key global-map [(control backspace)] 'backward-kill-word)
+(define-key global-map [(control delete)] 'kill-word)
+
+; Standard Qt/KDE shortcuts: Control Pageup and Pagedown
+(define-key global-map [(control prior)] 'beginning-of-buffer)
+(define-key global-map [(control next)] 'end-of-buffer)
+
 ; currently no binding for header-protection and add-file-to-makefile-am,
 ; you need to call them from M-x
 
